colour.colorimetry.lefs Module — Colour 0.3.0 documentation

# colour.colorimetry.lefs Module

## Luminous Efficiency Functions Spectral Power Distributions

Defines luminous efficiency functions computation related objects.

See also

Luminous Efficiency Functions IPython Notebook colour.colorimetry.dataset.lefs, colour.colorimetry.spectrum.SpectralPowerDistribution

References

[1] | http://en.wikipedia.org/wiki/Mesopic#Mesopic_weighting_function (Last accessed 20 June 2014)

`colour.colorimetry.lefs.` `mesopic_weighting_function`(wavelength, Lp, source=u'Blue Heavy', method=u'MOVE', photopic_lef=<colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8fd0>, scotopic_lef=<colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e061d0>)

  Calculates the mesopic weighting function factor at given wavelength \(\lambda\) using the photopic luminance \(L_p\).

  Parameters: | wavelength (numeric) – Wavelength \(\lambda\) to calculate the mesopic weighting function factor. Lp (numeric) – Photopic luminance \(L_p\). source (unicode) – (‘Blue Heavy’, ‘Red Heavy’), Light source colour temperature. method (unicode) – (‘MOVE’, ‘LRC’), Method to calculate the weighting factor. photopic_lef (SpectralPowerDistribution) – \(V(\lambda)\) photopic luminous efficiency function. scotopic_lef (SpectralPowerDistribution) – \(V^\prime(\lambda)\) scotopic luminous efficiency function.
  Returns: | Mesopic weighting function factor.
  Return type: | numeric
  Raises: | `KeyError` – If wavelength \(\lambda\) is not available in either luminous efficiency function.

  Examples

      >>> mesopic_weighting_function(500, 0.2)
      0.7052200...

`colour.colorimetry.lefs.` `mesopic_luminous_efficiency_function`(Lp, source=u'Blue Heavy', method=u'MOVE', photopic_lef=<colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8fd0>, scotopic_lef=<colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e061d0>)

  Returns the mesopic luminous efficiency function \(V_m(\lambda)\) for given photopic luminance \(L_p\).

  Parameters: | Lp (numeric) – Photopic luminance \(L_p\). source (unicode) – (‘Blue Heavy’, ‘Red Heavy’), Light source colour temperature. method (unicode) – (‘MOVE’, ‘LRC’), Method to calculate the weighting factor. photopic_lef (SpectralPowerDistribution) – \(V(\lambda)\) photopic luminous efficiency function. scotopic_lef (SpectralPowerDistribution) – \(V^\prime(\lambda)\) scotopic luminous efficiency function.
  Returns: | Mesopic luminous efficiency function \(V_m(\lambda)\).
  Return type: | SpectralPowerDistribution

  Examples

      >>> mesopic_luminous_efficiency_function(0.2)
      <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x...>